"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
const isMedia = (0, util_1.is)('media element');
exports.default = {
    tagName: 'video',
    getCategories(element) {
        const categories = ['flow content', 'phrasing content', 'embedded content', 'palpable content'];
        if (element.hasAttribute('controls')) {
            categories.push('interactive content');
        }
        return categories;
    },
    validateContext(element) {
        const result = [];
        return result;
    },
    validateContent(element) {
        const result = [];
        const hasSrcAttribute = element.hasAttribute('src');
        const contentModelParent = (0, util_1.getContentModelParent)(element);
        const rule = contentModelParent && (0, util_1.getRule)(contentModelParent);
        if (rule) {
            element.childNodes = element.childNodes.filter(child => {
                if (!hasSrcAttribute
                    && (0, util_1.isTag)('source', child)) {
                    return false;
                }
                if ((0, util_1.isTag)('track', child)) {
                    return false;
                }
                return true;
            });
            result.push(...rule.validateContent(element));
        }
        (0, util_1.walkDescendants)(element, descendant => {
            if (isMedia(descendant)) {
                result.push({
                    expect: 'with no media element descendants',
                    got: (0, util_1.getNodeInfo)(descendant),
                    target: descendant
                });
            }
        });
        return result;
    }
};
//# sourceMappingURL=video.js.map